/*
** 1999-05-24 -	A rewritten style selection dialog module. Very handy.
*/

extern Style *	sdl_dialog_sync_new_wait(StyleInfo *si, Style *ignore);
